"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const CircularProgress_1 = tslib_1.__importDefault(require("@material-ui/core/CircularProgress"));
const Paper_1 = tslib_1.__importDefault(require("@material-ui/core/Paper"));
const react_1 = tslib_1.__importStar(require("react"));
const services_1 = require("../services");
const hooks_1 = require("../hooks");
const page_widgets_1 = require("./page-widgets");
const style_1 = require("./page-widgets/style");
exports.Page = props => {
    const viewerState = hooks_1.useViewerState();
    const page = hooks_1.usePreviewImage(props.imageIndex);
    const commentState = hooks_1.useCommentState();
    const [isActive, setIsActive] = react_1.default.useState(page.image && viewerState.activePages.includes(page.image.Index));
    react_1.useEffect(() => {
        setIsActive(page.image && viewerState.activePages.includes(page.image.Index));
    }, [page.image, viewerState.activePages]);
    const [imgUrl, setImgUrl] = react_1.useState((page.image && (props.image === 'preview' ? page.image.PreviewImageUrl : page.image.ThumbnailImageUrl)) || '');
    react_1.useEffect(() => {
        setImgUrl((page.image && (props.image === 'preview' ? page.image.PreviewImageUrl : page.image.ThumbnailImageUrl)) || '');
    }, [page.image, props.image]);
    const [imageRotation, setImageRotation] = react_1.useState(services_1.ImageUtil.normalizeDegrees((page.image && page.image.Attributes && page.image.Attributes.degree) || 0));
    const [imageRotationRads, setImageRotationRads] = react_1.useState(((imageRotation % 180) * Math.PI) / 180);
    react_1.useEffect(() => {
        const newRotation = services_1.ImageUtil.normalizeDegrees((page.image && page.image.Attributes && page.image.Attributes.degree) || 0);
        setImageRotation(newRotation);
        setImageRotationRads(((newRotation % 180) * Math.PI) / 180);
    }, [page.image]);
    const [relativeImageSize, setRelativeImageSize] = react_1.useState(services_1.ImageUtil.getImageSize({
        width: props.viewportWidth,
        height: props.viewportHeight,
    }, {
        width: (page.image && page.image.Width) || 0,
        height: (page.image && page.image.Height) || 0,
        rotation: (page.image && page.image.Attributes && page.image.Attributes.degree) || 0,
    }, props.zoomMode, props.zoomLevel, props.fitRelativeZoomLevel));
    react_1.useEffect(() => {
        setRelativeImageSize(services_1.ImageUtil.getImageSize({
            width: props.viewportWidth,
            height: props.viewportHeight,
        }, {
            width: (page.image && page.image.Width) || 0,
            height: (page.image && page.image.Height) || 0,
            rotation: (page.image && page.image.Attributes && page.image.Attributes.degree) || 0,
        }, props.zoomMode, props.zoomLevel, props.fitRelativeZoomLevel));
    }, [
        page.image,
        props.fitRelativeZoomLevel,
        props.viewportHeight,
        props.viewportWidth,
        props.zoomLevel,
        props.zoomMode,
    ]);
    const [boundingBox, setBoundingBox] = react_1.useState(services_1.ImageUtil.getRotatedBoundingBoxSize({
        width: (page.image && page.image.Width) || 0,
        height: (page.image && page.image.Height) || 0,
    }, imageRotation));
    react_1.useEffect(() => {
        setBoundingBox(services_1.ImageUtil.getRotatedBoundingBoxSize({
            width: (page.image && page.image.Width) || 0,
            height: (page.image && page.image.Height) || 0,
        }, imageRotation));
    }, [imageRotation, page.image]);
    const [diffHeight, setDiffHeight] = react_1.useState(Math.sin(imageRotationRads) * ((relativeImageSize.height - relativeImageSize.width) / 2));
    react_1.useEffect(() => {
        setDiffHeight(Math.sin(imageRotationRads) * ((relativeImageSize.height - relativeImageSize.width) / 2) || 0);
    }, [imageRotationRads, relativeImageSize.height, relativeImageSize.width]);
    const [imageTransform, setImageTransform] = react_1.useState(`translateY(${diffHeight}px) rotate(${imageRotation}deg)`);
    react_1.useEffect(() => {
        setImageTransform(`translateY(${diffHeight}px) rotate(${imageRotation}deg)`);
    }, [diffHeight, imageRotation]);
    const handleMarkerPlacement = react_1.useCallback((event) => {
        if (!viewerState.isPlacingCommentMarker) {
            return;
        }
        const newCommentMarker = {
            x: event.nativeEvent.offsetX / (relativeImageSize.height / ((page.image && page.image.Height) || 1)) -
                style_1.MARKER_SIZE,
            y: event.nativeEvent.offsetY / (relativeImageSize.height / ((page.image && page.image.Height) || 1)) -
                style_1.MARKER_SIZE,
            id: 'draft',
        };
        commentState.setDraft(newCommentMarker);
    }, [commentState, page.image, relativeImageSize.height, viewerState.isPlacingCommentMarker]);
    return (react_1.default.createElement(Paper_1.default, { elevation: isActive ? 8 : 2, className: props.elementName, style: { margin: props.margin } },
        react_1.default.createElement("div", { style: {
                padding: 0,
                overflow: 'hidden',
                width: relativeImageSize.width - 2 * props.margin,
                height: relativeImageSize.height - 2 * props.margin,
                position: 'relative',
            }, onClick: ev => {
                props.onClick(ev);
                handleMarkerPlacement(ev);
            } },
            page.image && props.showWidgets ? (react_1.default.createElement("div", null,
                react_1.default.createElement(page_widgets_1.ShapesWidget, { draftCommentMarker: commentState.draft, zoomRatio: relativeImageSize.height / page.image.Height, page: page.image, viewPort: { height: relativeImageSize.height, width: relativeImageSize.width } }))) : null,
            react_1.default.createElement("span", { style: { display: 'flex', justifyContent: 'center' } }, imgUrl ? (react_1.default.createElement("img", { src: `${imgUrl}${viewerState.showWatermark ? '?watermark=true' : ''}`, alt: "", style: {
                    transition: 'transform .1s ease-in-out',
                    width: `${100 * boundingBox.zoomRatio}%`,
                    height: `${100 * boundingBox.zoomRatio}%`,
                    transform: imageTransform,
                } })) : (react_1.default.createElement(CircularProgress_1.default, { style: { marginTop: '50%' } }))))));
};
//# sourceMappingURL=Page.js.map