"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const client_utils_1 = require("@sensenet/client-utils");
const semaphore_async_await_1 = tslib_1.__importDefault(require("semaphore-async-await"));
const hooks_react_1 = require("@sensenet/hooks-react");
const Enums_1 = require("../Enums");
const hooks_1 = require("../hooks");
const defaultDocumentData = {
    documentName: '',
    documentType: '',
    fileSizekB: 0,
    hostName: '',
    idOrPath: 0,
    pageAttributes: [],
    pageCount: Enums_1.PreviewState.Loading,
    shapes: {
        annotations: [],
        highlights: [],
        redactions: [],
    },
    error: undefined,
};
exports.defaultDocumentDataContextValue = {
    documentData: defaultDocumentData,
    updateDocumentData: () => undefined,
};
exports.DocumentDataContext = react_1.default.createContext(exports.defaultDocumentDataContextValue);
exports.DocumentDataProvider = ({ children }) => {
    const api = hooks_1.useDocumentViewerApi();
    const doc = hooks_1.useViewerSettings();
    const repo = hooks_react_1.useRepository();
    const [documentData, setDocumentData] = react_1.useState(defaultDocumentData);
    const [loadLock] = react_1.useState(new semaphore_async_await_1.default(1));
    react_1.useEffect(() => {
        const ac = new AbortController();
        (() => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            try {
                yield loadLock.acquire();
                setDocumentData(defaultDocumentData);
                while (documentData.pageCount === Enums_1.PreviewState.Loading && !ac.signal.aborted) {
                    const result = yield api.getDocumentData({
                        hostName: repo.configuration.repositoryUrl,
                        idOrPath: doc.documentIdOrPath,
                        version: doc.version,
                        abortController: ac,
                    });
                    setDocumentData(result);
                    if (result.pageCount === Enums_1.PreviewState.Loading) {
                        yield client_utils_1.sleepAsync(4000);
                    }
                    else {
                        break;
                    }
                }
            }
            catch (error) {
                if (!ac.signal.aborted) {
                    setDocumentData(Object.assign(Object.assign({}, defaultDocumentData), { pageCount: Enums_1.PreviewState.ClientFailure, error: error.toString() }));
                    throw error;
                }
            }
            finally {
                loadLock.release();
            }
        }))();
        return () => ac.abort();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [api, doc.documentIdOrPath, repo.configuration.repositoryUrl, doc.version]);
    const updateDocumentData = react_1.useCallback((newDocData) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
        const merged = client_utils_1.deepMerge(documentData, newDocData);
        if (JSON.stringify(documentData) !== JSON.stringify(merged)) {
            try {
                yield loadLock.acquire();
                setDocumentData(merged);
            }
            finally {
                loadLock.release();
            }
        }
    }), [documentData, loadLock]);
    if (!documentData.idOrPath) {
        return null;
    }
    return (react_1.default.createElement(exports.DocumentDataContext.Provider, { value: { documentData, updateDocumentData } }, children));
};
//# sourceMappingURL=document-data.js.map